==> pip_services4_observability-0.0.4.tar.gz: pip_services4_observability-0.0.4/setup.py <==
"""
Pip.Services Logic
--------------------

Pip.Services is an open-source library of basic microservices.
pip_services4_observability package provides basic abstractions portable across variety of languages.

Links
`````

* `website <http://github.com/pip-services/pip-services>`
* `development version <https://github.com/pip-services4/pip-services4-python/pip-services4-observability-python>`

"""

from setuptools import setup
from setuptools import find_packages

try:
    readme = open('README.md').read()
except:
    readme = __doc__

setup(
    name='pip_services4_observability',
    version='0.0.4',
    url='https://github.com/pip-services4/pip-services4-python/pip-services4-observability-python',
    license='MIT',
    description='Observability components for Pip.Services in Python',
    author='Conceptual Vision Consulting LLC',
    author_email='seroukhov@gmail.com',
    long_description=readme,
    long_description_content_type="text/markdown",
    packages=find_packages(exclude=['config', 'data', 'test']),
    include_package_data=True,
    zip_safe=True,
    platforms='any',
    install_requires=[
        'pip_services4_commons >= 0.0.1, < 1.0',
        'pip_services4_components >= 0.0.2, < 1.0',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]    
)

==> pip_services4_observability-0.0.5.tar.gz: pip_services4_observability-0.0.5/setup.py <==
"""
Pip.Services Logic
--------------------

Pip.Services is an open-source library of basic microservices.
pip_services4_observability package provides basic abstractions portable across variety of languages.

Links
`````

* `website <http://github.com/pip-services/pip-services>`
* `development version <https://github.com/pip-services4/pip-services4-python/tree/main/pip-services4-observability-python>`

"""

from setuptools import setup
from setuptools import find_packages

try:
    readme = open('README.md').read()
except:
    readme = __doc__

setup(
    name='pip_services4_observability',
    version='0.0.5',
    url='https://github.com/pip-services4/pip-services4-python/tree/main/pip-services4-observability-python',
    license='MIT',
    description='Observability components for Pip.Services in Python',
    author='Conceptual Vision Consulting LLC',
    author_email='seroukhov@gmail.com',
    long_description=readme,
    long_description_content_type="text/markdown",
    packages=find_packages(exclude=['config', 'data', 'test']),
    include_package_data=True,
    zip_safe=True,
    platforms='any',
    install_requires=[
        'pip_services4_commons >= 0.0.1, < 1.0',
        'pip_services4_components >= 0.0.2, < 1.0',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]    
)
